summaryrefslogtreecommitdiffstats
path: root/src/tag.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tag.cpp')
-rw-r--r--src/tag.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/tag.cpp b/src/tag.cpp
index 7d6e657..645b0da 100644
--- a/src/tag.cpp
+++ b/src/tag.cpp
@@ -724,7 +724,7 @@ void IndentedMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool ac
TQPen pen = painter->pen();
TQFont font = painter->font();
- int iconSize = KIcon::SizeSmall;
+ int iconSize = TDEIcon::SizeSmall;
int iconMargin = StateMenuItem::iconMargin();
/* When an item is disabled, it often have a 3D sunken look.
@@ -743,8 +743,8 @@ void IndentedMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool ac
} else
drawingEtchedText = !enabled && !active && painter->pen().color() == cg.light();
if (!m_icon.isEmpty() && !drawingEtchedText) {
- TQPixmap icon = kapp->iconLoader()->loadIcon(m_icon, KIcon::Small, iconSize,
- (enabled ? (active ? KIcon::ActiveState : KIcon::DefaultState) : KIcon::DisabledState),
+ TQPixmap icon = kapp->iconLoader()->loadIcon(m_icon, TDEIcon::Small, iconSize,
+ (enabled ? (active ? TDEIcon::ActiveState : TDEIcon::DefaultState) : TDEIcon::DisabledState),
/*path_store=*/0L, /*canReturnNull=*/true);
painter->drawPixmap(x, y + (h-iconSize)/2, icon);
}
@@ -770,7 +770,7 @@ void IndentedMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool ac
TQSize IndentedMenuItem::sizeHint()
{
- int iconSize = KIcon::SizeSmall;
+ int iconSize = TDEIcon::SizeSmall;
int iconMargin = StateMenuItem::iconMargin();
TQSize textSize = TQFontMetrics(TDEGlobalSettings::menuFont()).size( AlignLeft | AlignVCenter | ShowPrefix | DontClip, m_text );
return TQSize(iconSize + iconMargin + textSize.width(), textSize.height());
@@ -793,7 +793,7 @@ void StateMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool activ
TQPen pen = painter->pen();
TQFont font = painter->font();
- int iconSize = 16; // We use 16 instead of KIcon::SizeSmall (the size of icons in menus) because tags will always be 16*16 icons
+ int iconSize = 16; // We use 16 instead of TDEIcon::SizeSmall (the size of icons in menus) because tags will always be 16*16 icons
if (!active && m_state->backgroundColor().isValid())
painter->fillRect(x/*-1*/, y/*-1*/, w/*+2*/, h/*+2*/, m_state->backgroundColor());
@@ -813,8 +813,8 @@ void StateMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool activ
} else
drawingEtchedText = !enabled && !active && painter->pen().color() == cg.light();
if (!m_state->emblem().isEmpty() && !drawingEtchedText) {
- TQPixmap icon = kapp->iconLoader()->loadIcon(m_state->emblem(), KIcon::Small, iconSize,
- (enabled ? (active ? KIcon::ActiveState : KIcon::DefaultState) : KIcon::DisabledState),
+ TQPixmap icon = kapp->iconLoader()->loadIcon(m_state->emblem(), TDEIcon::Small, iconSize,
+ (enabled ? (active ? TDEIcon::ActiveState : TDEIcon::DefaultState) : TDEIcon::DisabledState),
/*path_store=*/0L, /*canReturnNull=*/true);
painter->drawPixmap(x, y + (h-iconSize)/2, icon);
}
@@ -843,7 +843,7 @@ void StateMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool activ
TQSize StateMenuItem::sizeHint()
{
- int iconSize = 16; // We use 16 instead of KIcon::SizeSmall (the size of icons in menus) because tags will always be 16*16 icons
+ int iconSize = 16; // We use 16 instead of TDEIcon::SizeSmall (the size of icons in menus) because tags will always be 16*16 icons
TQFont theFont = m_state->font(TDEGlobalSettings::menuFont());
TQSize textSize = TQFontMetrics(theFont).size( AlignLeft | AlignVCenter | ShowPrefix | DontClip, m_name );
return TQSize(iconSize + iconMargin() + textSize.width(), textSize.height());